///////////////////////////////////////////////////////////////////////
// KeypadTest.cpp
//
// Sample application for
// 720020-1161x (Keypad helper class)
//
// For more information, see the header in Keypad.cpp
///////////////////////////////////////////////////////////////////////// 

#include <windows.h>
#include "keypad.h"


/////////////////////////////////////////////////////////////
// NOTE: For tyhe AGX, you must have ADSmartIO rev 5 or greater for this to work!
/////////////////////////////////////////////////////////////

// define the mappings for our 16 key keypad
//
// [ a  ] [ e  ] [  ALT  ] [ esc  ]
// [ b  ] [ f  ] [  tab  ] [ ctrl ]
// [ c  ] [ g  ] [ pg up ] [windws]
// [ <- ] [ -> ] [ pg dn ] [ shft ]
//
Keypad::MAPKEY keymap[16] = 
{ 
	{  0, 0x41 }, 
	{  1, 0x42 }, 
	{  2, 0x43 }, 
	{  3, VK_LEFT }, 
	{  4, 0x44 }, 
	{  5, 0x45 }, 
	{  6, 0x46 }, 
	{  7, VK_RIGHT },		// right cursor arrow
	{  8, VK_MENU },		// ALT key
	{  9, VK_TAB }, 
	{ 10, VK_PRIOR },		// page up
	{ 11, VK_NEXT },		// page down
	{ 12, VK_ESCAPE }, 
	{ 13, VK_CONTROL }, 
	{ 14, VK_LWIN },        // windows key
	{ 15, VK_SHIFT } 
};

int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	MSG		msg;
	
	Keypad *keypad = new Keypad();

	keypad->SetMap(keymap, 4, 4);

	keypad->Start();

	// message pump
	while(GetMessage(&msg, NULL, 0, 0))
	{
		TranslateMessage(&msg);
		DispatchMessage(&msg);
	}

	keypad->Stop();
	
	delete keypad;

	return 0;
}